OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Rangt lykilorð",
    "The new password can not be the same as the previous one" : "Nýja lykilorðið má ekki vera eins og það gamla",
    "No user supplied" : "Enginn notandi gefinn",
    "Authentication error" : "Villa við auðkenningu",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
    "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
    "Unable to change password" : "Ekki tókst að breyta lykilorði",
    "%s password changed successfully" : "Það tókst að breyta lykilorði %s",
    "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL er að nota úrelda útgáfu af %s (%s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %s virki ekki sem skyldi.",
    "A problem occurred, please check your log files (Error: %s)" : "Vandamál kom upp, skoðaðu yfir annálana þína (Villa: %s)",
    "Migration Completed" : "Yfirfærslu lokið",
    "Group already exists." : "Hópur er þegar til.",
    "Unable to add group." : "Ekki tókst að bæta hóp við.",
    "Unable to delete group." : "Get ekki eytt hópi.",
    "log-level out of allowed range" : "annálsstig utan leyfðra marka",
    "Saved" : "Vistað",
    "test email settings" : "prófa tölvupóststillingar",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
    "Email sent" : "Tölvupóstur sendur",
    "You need to set your user email before being able to send test emails." : "Þú verður að gefa upp netfangið þitt svo að þú getir sent prófunarpósta.",
    "Couldn't change the email address because the user does not exist" : "Gat ekki breytt tölvupóstfanginu vegna þess að notandinn er ekki til",
    "Couldn't change the email address because the token is invalid" : "Gat ekki breytt tölvupóstfanginu vegna þess að teiknið er ógilt",
    "Invalid mail address" : "Ógilt tölvupóstfang",
    "A user with that name already exists." : "Nú þegar til notandi með þetta nafn.",
    "Unable to create user." : "Gat ekki búið til notanda.",
    "Your %s account was created" : "%s notandaaðgangurinn þinn var búinn til",
    "Unable to delete user." : "Get ekki eytt notanda.",
    "Forbidden" : "Bannað",
    "Invalid user" : "Ógildur notandi",
    "Unable to change mail address" : "Get ekki breytt tölvupóstfangi",
    "Email has been changed successfully." : "Það tókst að breyta tölvupóstfanginu þínu.",
    "An email has been sent to this address for confirmation" : "Póstur var sendur á þetta tölvupóstfang til staðfestingar",
    "No email was sent because you already sent one recently. Please try again later." : "Enginn póstur var sendur, því stutt er síðan þú sendir annan. Reyndu aftur síðar.",
    "Your full name has been changed." : "Fullu nafni þínu hefur verið breytt.",
    "Unable to change full name" : "Get ekki breytt fullu nafni",
    "%s email address confirm" : "Staðfesting á tölvupóstfangi %s",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Gat ekki sent staðfestingarpóst fyrir breytingu á tölvupóstfangi. Hafðu samband við kerfisstjóra.",
    "%s email address changed successfully" : "Tókst að breyta tölvupóstfangi %s",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Gat ekki sent póst um breytingu á tölvupóstfangi. Hafðu samband við kerfisstjóra.",
    "Unable to enable/disable user." : "Get ekki virkjað/afvirkjað notanda.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Íslenska",
    "Language changed" : "Tungumáli breytt",
    "Invalid request" : "Ógild fyrirspurn",
    "Admins can't remove themself from the admin group" : "Stjórnendur geta ekki fjarlægt sjálfa sig úr stjórnendahóp",
    "Unknown user" : "Óþekktur notandi",
    "Couldn't remove app." : "Gat ekki fjarlægt forrit.",
    "Official" : "Opinbert",
    "Approved" : "Samþykkt",
    "All" : "Allt",
    "Enabled" : "Virkt",
    "Not enabled" : "Óvirkt",
    "No apps found for your version" : "Engin forrit fundust fyrir útgáfuna þína",
    "The app will be downloaded from the app store" : "Forritinu verður hlaðið niður úr forritabúðinni",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Opinber forrit eru þróuð af og innan ownCloud samfélagsins. Þau virka með kjarnaeiginleikum ownCloud og eru tilbúin til notkunar í raunvinnslu.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Samþykkt forrit eru þróuð af treystum forriturum og hafa gengist undir lauslegar öryggisprófanir. Þau eru í virku viðhaldi í opnum hugbúnaðarsöfnum og umsjónarmenn þeirra dæma þau nógu stöðug til notkunar í allri venjulegri vinnslu.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Þetta forrit hefur ekki verið öryggisprófað, er nýtt erða þekkt fyrir ótöðugleika við vissar aðstæður. Uppsetning er á þína ábyrgð.",
    "Please wait...." : "Andartak....",
    "Error while disabling app" : "Villa við að afvirkja forrit",
    "Disable" : "Gera óvirkt",
    "Enable" : "Virkja",
    "Error while enabling app" : "Villa við að virkja forrit",
    "Error: this app cannot be enabled because it makes the server unstable" : "Villa: ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan",
    "Error: could not disable broken app" : "Villa: gat ekki gert bilaða forritið óvirkt",
    "Error while disabling broken app" : "Villa við að gera bilaða forritið óvirkt",
    "Updating...." : "Uppfæri...",
    "Error while updating app" : "Villa við að uppfæra forrit",
    "Updated" : "Uppfært",
    "Uninstalling ...." : "Tek út uppsetningu ....",
    "Error while uninstalling app" : "Villa við að fjarlægja forrit",
    "Uninstall" : "Henda út",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
    "App update" : "Uppfærsla forrits",
    "Experimental" : "Á tilraunastigi",
    "No apps found for {query}" : "Engin forrit fundust fyrir \"{query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ertu viss um að þú viljir bæta \"{domain}\" við sem treystu léni?",
    "Add trusted domain" : "Bæta við treystu léni",
    "Migration in progress. Please wait until the migration is finished" : "Yfirfærsla er í gangi. Dokaðu við þar til henni er lokið",
    "Migration started …" : "Yfirfærsla hafin...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Villa kom upp. Sendu inn ASCII-kóðað PEM-skilríki.",
    "Valid until {date}" : "Gildir til {date}",
    "Delete" : "Eyða",
    "Disconnect" : "Aftengjast",
    "Error while loading browser sessions and device tokens" : "Villa við að hlaða inn vafrasetum og teiknum fyrir tæki",
    "Error while creating device token" : "Villa við að búa til teikn fyrir tækið",
    "Error while deleting the token" : "Villa kom upp við að eyða teikninu",
    "Sending..." : "Sendi...",
    "Failed to change the email address." : "Gat ekki breyta tölvupóstfanginu.",
    "Email changed successfully." : "Tókst að breyta tölvupóstfangi.",
    "An error occurred: {message}" : "Villa kom upp: {message}",
    "Select a profile picture" : "Veldu einkennismynd",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Svo-svo lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Groups" : "Hópar",
    "Unable to delete {objName}" : "Get ekki eytt {objName}",
    "Error creating group: {message}" : "Villa við að búa til hóp: {message}",
    "A valid group name must be provided" : "Skráðu inn gilt heiti á hópi",
    "deleted {groupName}" : "eyddi {groupName}",
    "undo" : "afturkalla",
    "never" : "aldrei",
    "deleted {userName}" : "eyddi {userName}",
    "add group" : "bæta við hópi",
    "Invalid quota value \"{val}\"" : "Óleyfilegt gildi kvóta \"{val}\"",
    "enabled" : "virkt",
    "disabled" : "óvirkt",
    "User {uid} has been {state}!" : "Notandi {uid} hefur verið {state}!",
    "no group" : "enginn hópur",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Breyting á þessu lykilorði mun valda gagnatapi, þar sem gagnaendurheimt er ekki tiltæk fyrir þennan notanda",
    "Password successfully changed" : "Lykilorðinu hefur verið breytt",
    "A valid username must be provided" : "Skráðu inn gilt notandanafn",
    "Error creating user: {message}" : "Villa við að búa til notanda: {message}",
    "A valid password must be provided" : "Skráðu inn gilt lykilorð",
    "A valid email must be provided" : "Skráðu inn gilt tölvupóstfang",
    "Use the following link to confirm your changes to the email address: {link}" : "Notaðu eftirfarandi veftengil til að staðfesta breytingar á tölvupóstfangi: {link}",
    "Email address changed to {mailAddress} successfully." : "Tókst að breyta tölvupóstfangi í {mailAddress}.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hæ þú,<br><br>bara að láta þig vita að þú átt núna %s aðgang.<br><br>Notandanafnið þitt: %s<br>Tengstu honum: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Til hamingju!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hæ þú,\n\nbara að láta þig vita að þú átt núna %s aðgang.\n\nNotandanafnið þitt: %s\nTengstu honum: %s\n\n",
    "User documentation" : "Hjálparskjöl notenda",
    "Administrator documentation" : "Hjálparskjöl stjórnanda",
    "Online documentation" : "Handbækur/skjölun á netinu",
    "Forum" : "Vefspjall",
    "Issue tracker" : "Skrásetjari (tracker)",
    "Commercial support" : "Gjaldskyld tækniaðstoð",
    "Apps Management" : "Forritastjórnun",
    "Developer documentation" : "Skjölun fyrir þróunaraðila",
    "by %s" : "frá %s",
    "%s-licensed" : "%s-notkunarleyfi",
    "Documentation:" : "Hjálparskjöl:",
    "Admin documentation" : "Hjálparskjöl kerfisstjóra",
    "Visit website" : "Heimsækja vefsvæðið",
    "Report a bug" : "Tilkynna um villu",
    "Show description …" : "Birta lýsingu …",
    "Hide description …" : "Fela lýsingu …",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu ownCloud. Þetta mun gefa villu í ownCloud 11 og nýrri.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu ownCloud. Þetta mun gefa villu í ownCloud 11 og nýrri.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
    "Enable only for specific groups" : "Einungis fyrir sérstaka hópa",
    "Uninstall App" : "Fjarlægja/Henda út forriti",
    "Show enabled apps" : "Birta virk forrit",
    "Show disabled apps" : "Birta óvirk forrit",
    "Cron" : "CRON",
    "Last cron job execution: %s." : "Síðasta keyrsla cron-verks: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Síðasta keyrsla cron-verks: %s. Eitthvað er ekki eins og það á að sér að vera.",
    "Cron was not executed yet!" : "Cron hefur ekki ennþá verið keyrt!",
    "Open documentation" : "Opna hjálparskjöl",
    "Execute one task with each page loaded" : "Framkvæma eitt verk með hverri innhlaðinni síðu",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 15 mínútna fresti yfir http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 15 mínútna fresti.",
    "SSL Root Certificates" : "SSL-rótarskilríki",
    "Common Name" : "Almennt heiti",
    "Valid until" : "Gildir til",
    "Issued By" : "Gefið út af",
    "Valid until %s" : "Gildir til %s",
    "Import root certificate" : "Flytja inn rótarskilríki",
    "Server-side encryption" : "Dulritun á þjóni",
    "Enable server-side encryption" : "Virkja dulritun á þjóni",
    "Please read carefully before activating server-side encryption: " : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni: ",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Þegar dulritun er virkjuð, munu frá þeim tímapunkti allar skrár sem sendar eru inn á þjóninn verða dulritaðar inni á honum. Einungis mun verða hægt að afvirkja dulritun síðar, ef virka dulritunareiningin styður þá aðgerð, og ef allar forsendur (t.d. að setja endurheimtulykil) eru uppfylltar.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Dulritun ein og sér tryggir ekki öryggi kerfisins. Endilega skoðaðu hjálparskjölownCloud um hvernig dulritunarforritið virkar, og dæmi um hvaða uppsetningar eru studdar.",
    "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
    "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
    "Enable encryption" : "Virkja dulritun",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Engin dulritunareining hlaðin inn, virkjaðu dulritunareiningu í valmynd forritsins.",
    "Select default encryption module:" : "Veldu sjálfgefna dulritunareiningu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefna dulritunareiningu\" og keyrðu 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju.",
    "Start migration" : "Hefja yfirfærslu",
    "Sharing" : "Deiling",
    "Allow apps to use the Share API" : "Leyfa forritum að nota Share API",
    "Allow users to share via link" : "Leyfa notendum að deila með tengli",
    "Allow public uploads" : "Leyfa opinberar innsendingar",
    "Enforce password protection" : "Krefjast verndunar með aðgangsorði",
    "Set default expiration date" : "Setja sjálfgefinn gildistíma",
    "Allow users to send mail notification for shared files" : "Leyfa notendum að senda tilkynningar í tölvupósti vegna deildra skráa",
    "Allow users to share file via social media" : "Leyfa notendum að deila með samfélagsmiðlum",
    "Expire after " : "Rennur út eftir ",
    "days" : "daga",
    "Enforce expiration date" : "Krefjast dagsetningar á gildistíma",
    "Allow resharing" : "Leyfa endurdeilingu",
    "Allow sharing with groups" : "Leyfa deilingu með hópum",
    "Restrict users to only share with users in their groups" : "Takmarka notendur við að deila með notendum í þeirra eigin hópum",
    "Allow users to send mail notification for shared files to other users" : "Leyfa notendum að senda tilkynningar til annarra notenda í tölvupósti vegna deildra skráa",
    "Exclude groups from sharing" : "Undanskilja hópa frá því að deila",
    "These groups will still be able to receive shares, but not to initiate them." : "Þessir hópar munu samt geta tekið við deildum sameignum, en ekki geta útbúið þær.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Leyfa sjálfklárun notandanafns í deilingarglugga. Ef þetta er óvirkt þarf að setja inn fullt nafn notanda.",
    "Restrict enumeration to group members" : "Takmarka upptalningu við meðlimi hóps",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Allt (aflúsun, upplýsingar, viðvaranir, villur og alvarlegar aðvaranir)",
    "Info, warnings, errors and fatal issues" : "Upplýsingar, viðvaranir, villur og alvarlegar aðvaranir",
    "Warnings, errors and fatal issues" : "Viðvaranir, villur og alvarlegar aðvaranir",
    "Errors and fatal issues" : "Villur og alvarlegar aðvaranir",
    "Fatal issues only" : "Einungis alvarlegar aðvaranir",
    "Log" : "Annáll",
    "What to log" : "Hvað á að skrá í annál",
    "Download logfile (%s)" : "Sækja annál (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Annállinn er stærri en 100 MB.Þetta gæti tekið nokkra stund!",
    "None" : "Ekkert",
    "Login" : "Innskráning",
    "Plain" : "Einfalt",
    "NT LAN Manager" : "NT LAN stjórnun",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Póstþjónn",
    "This is used for sending out notifications." : "Þetta er notað til að senda út tilkynningar.",
    "Send mode" : "Sendihamur",
    "Encryption" : "Dulritun",
    "From address" : "Frá vistfangi",
    "mail" : "póstur",
    "Authentication method" : "Auðkenningarmáti",
    "Authentication required" : "Auðkenningar krafist",
    "Server address" : "Host nafn netþjóns",
    "Port" : "Gátt",
    "Credentials" : "Auðkenni",
    "SMTP Username" : "SMTP-notandanafn",
    "SMTP Password" : "SMTP-lykilorð",
    "Store credentials" : "Geyma auðkenni",
    "Test email settings" : "Prófa tölvupóststillingar",
    "Send email" : "Senda tölvupóst",
    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Þessu veldur væntanlega biðminni/hraðall á borð við Zend OPcache eða eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s eldra en útgáfa %2$s er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa %1$s verði sett upp.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-eininguna 'fileinfo' vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál. Skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin ↗</a> til að sjá nánari upplýsingar.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Færslulæsing skráa (transactional file locking) ætti að nota læsingu í vinnsluminni, en ekki hægvirka læsingu í gagnagrunni. Skoðaðu <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin ↗</a> til að sjá nánari upplýsingar.",
    "System locale can not be set to a one which supports UTF-8." : "Ekki var hægt að setja staðfærslu kerfisins á neina sem styður UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Þetta þýðir að það geta komið upp vandamál við að birta ákveðna stafi í skráaheitum.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Við mælum eindregið með því að þessir nauðsynlegu pakkar séu á kerfinu til stuðnings einnar af eftirfarandi staðfærslum: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite er notað sem gagnagrunnur. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sérstaklega þegar tölvu forrit er notað til samræmingar þá er ekki mælt með notkunn SQLite.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Til að yfirfæra í annan gagnagrunn skaltu nota skipanalínutólið: 'occ db:convert-type', eða lesa <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">hjálparskjölin ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Við mælum með því að virkja cron kerfisins, því aðrar aðferðir fyrir cron eru mögulega með takmarkanir varðandi afköst og áreiðanleika.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">uppsetningarleiðbeiningarnar  ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"#log-section\">annálnum</a>.",
    "All checks passed." : "Stóðst allar prófanir.",
    "System Status" : "Staða kerfis",
    "Tips & tricks" : "Ábendingar og góð ráð",
    "How to do backups" : "Hvernig á að taka öryggisafrit",
    "Advanced monitoring" : "Ítarleg vöktun",
    "Performance tuning" : "Fínstilling afkasta",
    "Improving the config.php" : "Bæting á config.php skránni",
    "Theming" : "Þemu",
    "Hardening and security guidance" : "Brynjun og öryggisleiðbeiningar",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "Desktop client" : "Skjáborðsforrit",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ef þú vilt styðja við verkefnið\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">taktu þátt í þróuninni</a>\n\t\teða\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">láttu orð út ganga</a>!",
    "Show First Run Wizard again" : "Birta Fyrsta-skiptis-leiðarvísinn aftur",
    "Profile picture" : "Einkennismynd",
    "Upload new" : "Senda inn nýtt",
    "Select from Files" : "Veldu skrár",
    "Remove image" : "Fjarlægja mynd",
    "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
    "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
    "Cancel" : "Hætta við",
    "Choose as profile picture" : "Veldu sem einkennismynd",
    "Full name" : "Fullt nafn",
    "No display name set" : "Ekkert birtingarnafn sett",
    "Email" : "Tölvupóstfang",
    "Your email address" : "Tölvupóstfangið þitt",
    "Change email" : "Breyta tölvupóstfangi",
    "Set email" : "Setja tölvupóstfang",
    "For password recovery and notifications" : "Fyrir tilkynningar og endurheimtingu lykilorðs",
    "No email address set" : "Ekkert tölvupóstfang sett",
    "You are member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
    "Password" : "Lykilorð",
    "Unable to change your password" : "Ekki tókst að breyta lykilorðinu þínu",
    "Current password" : "Núverandi lykilorð",
    "New password" : "Nýtt lykilorð",
    "Change password" : "Breyta lykilorði",
    "Language" : "Tungumál",
    "Help translate" : "Hjálpa við þýðingu",
    "Unlimited" : "Ótakmarkað",
    "You are using %s of %s" : "Þú notar %s af %s",
    "You are using %s of %s (%s %%)" : "Þú notar %s af %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Þróað af {communityopen}ownCloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} notkunarleyfinu.",
    "Sessions" : "Setur",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Þetta eru þau veftól, tölvur og símar sem núna eru skráð inn á aðganginn þinn.",
    "Browser" : "Vafri",
    "Most recent activity" : "Nýjasta virkni",
    "App passwords" : "Lykilorð forrita",
    "You've linked these apps." : "Þú hefur tengt þessi forrit.",
    "Name" : "Heiti",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Lykilorð forrits er aðgangskóði sem gefur forriti eða tæki heimild til að nota %s notandaaðganginn þinn.",
    "App name" : "Heiti forrits",
    "Create new app password" : "Búa til nýtt lykilorð forrits",
    "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
    "Username" : "Notandanafn",
    "Done" : "Lokið",
    "Version" : "Útgáfa",
    "Personal" : "Einka",
    "Admin" : "Stjórnun",
    "Error" : "Villa",
    "No panels for this section." : "Engin spjöld fyrir þennan hluta.",
    "Show enabled/disabled option" : "Birta valkost fyrir virkt/óvirkt",
    "Show storage location" : "Birta staðsetningu gagnageymslu",
    "Show last log in" : "Birta síðustu innskráningu",
    "Show user backend" : "Birta bakenda notanda",
    "Send email to new user" : "Senda tölvupóst til nýs notanda",
    "Show email address" : "Birta tölvupóstfang",
    "E-Mail" : "Tölvupóstfang",
    "Create" : "Búa til",
    "Admin Recovery Password" : "Endurheimtulykilorð kerfisstjóra",
    "Enter the recovery password in order to recover the users files during password change" : "Settu inn endurheimtulykilorð til að endurheimta skrár notandans við breytingu á lykilorði",
    "Add Group" : "Bæta við hópi",
    "Group" : "Hópur",
    "Everyone" : "Allir",
    "Admins" : "Kerfisstjórar",
    "Default Quota" : "Sjálfgefinn kvóti",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Settu inn geymslukvóta (t.d.: \"512 MB\" eða \"12 GB\")",
    "Other" : "Annað",
    "Full Name" : "Fullt nafn",
    "Group Admin for" : "Hópstjóri fyrir",
    "Quota" : "Kvóti",
    "Storage Location" : "Staðsetning gagnageymslu",
    "User Backend" : "Bakendi notanda",
    "Last Login" : "Síðasta innskráning",
    "change full name" : "breyta fullu nafni",
    "set new password" : "setja nýtt lykilorð",
    "change email address" : "breyta tölvupóstfangi",
    "Default" : "Sjálfgefið",
    "Change" : "Skipta um",
    "Share" : "Deila",
    "installing and updating apps via the market or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
    "White-listed Domains" : "Lén á lista yfir leyft",
    "Domain" : "Lén",
    "Add Domain" : "Bæta við léni",
    "CORS" : "CORS",
    "User ID" : "Auðkenni notanda",
    "Email address" : "Tölvupóstfang",
    "Invalid email address" : "Ógilt tölvupóstfang",
    "Extra field to display in autocomplete results" : "Aukareitur til að birta niðurstöður í sjálfvirkri orðaklárun",
    "Restrict users to only share with groups they are member of" : "Takmarka notendur við að deila með hópum sem þeir eru meðlimir í",
    "Default user and group share permissions" : "Sjálfgefnar heimildir deilingar notenda og hópa",
    "No Domains." : "Engin lén.",
    "Are you sure you want to remove this domain?" : "Ertu viss um að þú viljir fjarlægja þetta lén?",
    "Add" : "Bæta við",
    "Empty app name is not allowed." : "Autt heiti forrits er ekki leyft.",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Uppsetningarskráin er einungis lesanleg. Lagaðu uppsetninguna þína handvirkt með því að breyta sjálfri uppsetningaskránni í ritli.",
    "Email changed successfully for {user}." : "Tókst að breyta tölvupóstfangi fyrir {user}.",
    "You are not a member of any groups." : "Þú ert ekki meðlimur í neinum hópi.",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Ef um klasauppsetningu er að ræða, gakktu úr skugga um að config.php sé samstillt yfir alla hnútana.",
    "Wrong current password" : "Rangt núverandi lykilorð",
    "The new password cannot be the same as the previous one" : "Nýja lykilorðið má ekki vera eins og það fyrra"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
